## 0.3.2 (2025-05-14)

### Fix

- Timeout по умолчаниб 10 сек
- Добавлен patch метод

## 0.3.1 (2025-03-05)

### Fix

- Исключен host из headers при проксировании
- Исправление в получении тела запроса
- Изменена логика получения тела запроса
- Наименование сервисов при парсинге приводятся к верхнему регистру
- Добавлена обработка для заголовков без авторизации

## 0.3.0 (2025-02-15)

### Feat

- Добавлена возможность четния конфигов из нескольких файлов, или директории
- Реализовано получение хостов из env

## 0.2.0 (2025-01-24)

### Feat

- Добавлен AuthType body

## 0.1.3 (2025-01-16)

## 0.1.2 (2025-01-16)

### Fix

- Изменения gitlab ci под windows

## 0.1.0 (2025-01-16)

### Fix

- Имя файла gitlab-ci

## 0.0.1 (2025-01-16)
